==> catseye-fm-3.0.0.0.tar.gz: catseye-fm-3.0.0.0/fileshelf.h <==
/*
    Copyright 2007, 2008, 2009 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/



#ifndef FILESHELF_H_
#define FILESHELF_H_


#define SHELFNAMEID "shlf%d"
#define SHELFITEMNAME "s%dn%d"
#define SHELFITEMPATH "s%dp%d"
#define FILESHELFFILEIDENTIFIER "flshlf"
#define FILESHELFFILEPREPEND "FileShelf_"

enum {
	COL_FLSHLF_PATH = 0,
	COL_FLSHLF_NAME,
	COL_FLSHLF_SIZE,
	COL_FLSHLF_OWNER,
	COL_FLSHLF_GROUP,
	COL_FLSHLF_PERMISSION,
	COL_FLSHLF_ACCESSED,
	COL_FLSHLF_CHANGED,
	COL_FLSHLF_TARGET,
	COL_FLSHLF_FILETYPE,	//For e.g. for picture or video file this means jpg, mp3 and so on
	COL_FLSHLF_TIMESTAMPACCESSED,	//untouched timevalue from files
	COL_FLSHLF_TIMESTAMPCHANGED,
	COL_FLSHLF_TYPE_D,	//is it file, directory, link and so on, see 'man dirent'
	COL_FLSHLF_COLOR,
	COL_FLSHLF_INTERNAL,	//to mark items for delete ('D'), or mark missing items ('M)
	NUM_FLSHLF_COLS
};

gboolean oneFileShelfKeyPressedInView(GtkWidget *widget, GdkEventKey *event, gpointer data);
void AddItemToFileshelf (struct FileShelfObjectList *Shelf, char *cpName, char *cpPath, gboolean AddItInAllCases);
void DeleteFileshelfThings();
void openFileShelfTabContextMenu(GtkWidget *notebook, GdkEventButton *event, gpointer data);
void FileShelf_DeleteActiveTab();
void saveFileShelfs();
void loadFileShelfs(char *FileName);
int NewFileShelf(char *Name);
void updateFileshelf(GtkWidget *menuitem, gpointer data);
void RemoveMissingFiles (GtkWidget *menuitem, gpointer data);
int FileShelf_NameForNewShelf(GString *NewName);
void startItemsWithUserCommand_WraperforFileShelf(GtkWidget *menuitem, gpointer data);
void addItemsFromFileshelfToFileshelf_Helper(GtkTreeModel *model,GtkTreePath *TreePath,GtkTreeIter *iter,gpointer data);
void copyFileShelfToRightPannel(GtkWidget *menuitem, gpointer data);
void copyFileShelfToLeftPannel(GtkWidget *menuitem, gpointer data);
#endif /*FILESHELF_H_*/

==> catseye-fm-4.2.0.0.tar.gz: catseye-fm-4.2.0.0/fileshelf.h <==
/*
    Copyright 2007, 2008, 2009, 2010 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/



#ifndef FILESHELF_H_
#define FILESHELF_H_


#define SHELFNAMEID "shlf%d"
#define SHELFITEMNAME "s%dn%d"
#define SHELFITEMPATH "s%dp%d"
#define SHELFPREVIEW "shlfv%d"
#define FILESHELFFILEIDENTIFIER "flshlf"
#define FILESHELFFILEPREPEND "FileShelf_"

enum {
    COL_FLSHLF_PREVIEW = 0,
	COL_FLSHLF_PATH,
	COL_FLSHLF_NAME,
	COL_FLSHLF_SIZE,
	COL_FLSHLF_OWNER,
	COL_FLSHLF_GROUP,
	COL_FLSHLF_PERMISSION,
	COL_FLSHLF_ACCESSED,
	COL_FLSHLF_CHANGED,
	COL_FLSHLF_TARGET,
	COL_FLSHLF_FILETYPE,	//For e.g. for picture or video file this means jpg, mp3 and so on
	COL_FLSHLF_TIMESTAMPACCESSED,	//untouched timevalue from files
	COL_FLSHLF_TIMESTAMPCHANGED,
	COL_FLSHLF_TYPE_D,	//is it file, directory, link and so on, see 'man dirent'
	COL_FLSHLF_COLOR,
	COL_FLSHLF_INTERNAL,	//to mark items for delete ('D'), or mark missing items ('M)
	NUM_FLSHLF_COLS
};

gboolean oneFileShelfKeyPressedInView(GtkWidget *widget, GdkEventKey *event, gpointer data);
void AddItemToFileshelf (struct FileShelfObjectList *Shelf, char *cpName, char *cpPath, gboolean AddItInAllCases, int protocolMode);
void DeleteFileshelfThings();
void openFileShelfTabContextMenu(GtkWidget *notebook, GdkEventButton *event, gpointer data);
void FileShelf_DeleteActiveTab();
void saveFileShelfs();
void loadFileShelfs(char *FileName);
int NewFileShelf(char *Name);
void updateFileshelf(GtkWidget *menuitem, gpointer data);
void RemoveMissingFiles (GtkWidget *menuitem, gpointer data);
int FileShelf_NameForNewShelf(GString *NewName);
void startItemsWithUserCommand_WraperforFileShelf(struct FileShelfObjectList *Object);
void addItemsFromFileshelfToFileshelf_Helper(GtkTreeModel *model,GtkTreePath *TreePath,GtkTreeIter *iter,gpointer data);
void copyFileShelfToRightPannel(GtkWidget *menuitem, gpointer data);
void copyFileShelfToLeftPannel(GtkWidget *menuitem, gpointer data);
#endif /*FILESHELF_H_*/
